"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ExpandableBtnTray = void 0;
const gsap_1 = __importDefault(require("gsap"));
function ExpandableBtnTray(container, options) {
    var _a, _b, _c;
    let gap = (_a = options === null || options === void 0 ? void 0 : options.gap) !== null && _a !== void 0 ? _a : 10;
    let duration = (_b = options === null || options === void 0 ? void 0 : options.duration) !== null && _b !== void 0 ? _b : 0.5;
    let ease = (_c = options === null || options === void 0 ? void 0 : options.ease) !== null && _c !== void 0 ? _c : "Power1.easeOut";
    let topElement = (options === null || options === void 0 ? void 0 : options.topElement) || container.firstElementChild;
    const timeline = gsap_1.default.timeline({
        defaults: { duration: duration / 2 + 0.2, ease: ease },
    });
    const itemCount = container.children.length;
    const genericItem = container.children[0];
    const itemWidth = genericItem === null || genericItem === void 0 ? void 0 : genericItem.getBoundingClientRect().width;
    const itemHeight = genericItem === null || genericItem === void 0 ? void 0 : genericItem.getBoundingClientRect().height;
    const containerWidth = itemWidth + 2 * gap;
    const containerHeightInitial = itemHeight + 2 * gap;
    const containerHeightFinal = (itemHeight + gap) * itemCount + gap;
    container.style.position = "relative";
    container.style.height = containerHeightInitial + "px";
    container.style.width = containerWidth + "px";
    for (const item of container.children) {
        item.style.position = "absolute";
        item.style.top = gap + "px";
        item.style.left = gap + "px";
        item.style.zIndex = "0";
    }
    topElement.style.zIndex = "2";
    timeline
        .to(container, { height: containerHeightFinal })
        .to(container.children, {
        top: (i) => {
            return gsap_1.default.utils.mapRange(0, itemCount - 1, gap, containerHeightFinal - (gap + itemHeight), i);
        },
    }, "-=.2")
        .reversed(true);
    return {
        gsap: gsap_1.default,
        timeline,
        toggle: function () {
            timeline.reversed(!timeline.reversed());
        },
        open: function () {
            if (timeline.reversed())
                timeline.reversed(false);
        },
        close: function () {
            if (!timeline.reversed())
                timeline.reversed(true);
        },
    };
}
exports.ExpandableBtnTray = ExpandableBtnTray;
